MindRoot 9.10.0 documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# MindRoot Documentation

Welcome to the MindRoot documentation. This documentation is divided into two main sections:

- User Documentation: For end users who want to install, configure, and use MindRoot

- Developer Documentation: For developers who want to extend, contribute to, or understand MindRoot’s architecture

User Documentation:

- User Documentation
  - Installation
  - Starting MindRoot
  - LLM Plugin Installation
  - LLM API Key
  - Chat with Assistant
  - Install Plugins with Tools
  - Give Assistant a Programming Task
  - Embed Agent Chat on Your Website

Developer Documentation:

- Developer Documentation
  - Plugin Examples
  - API Reference
  - Plugin Development
  - Contributing
  - Architecture

# Indices and tables

- Index

- Module Index

- Search Page

# View Source Code

- viewcode

- Browse source code